==> icecat-31.5.0.en-US.win32.zip: icecat/browser/extensions/spyblock@gnu.org/defaults/prefs.js <==
// For description of these values see http://adblockplus.org/en/preferences

pref("extensions.adblockplus.currentVersion", "0.0");
pref("extensions.adblockplus.enabled", true);
pref("extensions.adblockplus.frameobjects", true);
pref("extensions.adblockplus.fastcollapse", false);
pref("extensions.adblockplus.showinstatusbar", false);
pref("extensions.adblockplus.detachsidebar", false);
pref("extensions.adblockplus.defaulttoolbaraction", 0);
pref("extensions.adblockplus.defaultstatusbaraction", 0);
pref("extensions.adblockplus.sidebar_key", "Accel Shift V, Accel Shift U");
pref("extensions.adblockplus.sendReport_key", "");
pref("extensions.adblockplus.filters_key", "Accel Shift E, Accel Shift F, Accel Shift O");
pref("extensions.adblockplus.enable_key", "");
pref("extensions.adblockplus.flash_scrolltoitem", true);
pref("extensions.adblockplus.previewimages", true);
pref("extensions.adblockplus.data_directory", "adblockplus");
pref("extensions.adblockplus.patternsbackups", 5);
pref("extensions.adblockplus.patternsbackupinterval", 24);
pref("extensions.adblockplus.whitelistschemes", "about chrome file irc moz-safe-about news resource snews x-jsd addbook cid imap mailbox nntp pop data javascript moz-icon");
pref("extensions.adblockplus.subscriptions_autoupdate", true);
pref("extensions.adblockplus.subscriptions_listurl", "https://adblockplus.org/subscriptions2.xml");
pref("extensions.adblockplus.subscriptions_fallbackurl", "https://adblockplus.org/getSubscription?version=%VERSION%&url=%SUBSCRIPTION%&downloadURL=%URL%&error=%ERROR%&channelStatus=%CHANNELSTATUS%&responseStatus=%RESPONSESTATUS%");
pref("extensions.adblockplus.subscriptions_fallbackerrors", 5);
pref("extensions.adblockplus.subscriptions_exceptionsurl", "https://easylist-downloads.adblockplus.org/exceptionrules.txt");
pref("extensions.adblockplus.subscriptions_exceptionscheckbox", true);
pref("extensions.adblockplus.documentation_link", "https://adblockplus.org/redirect?link=%LINK%&lang=%LANG%");
pref("extensions.adblockplus.savestats", true);
pref("extensions.adblockplus.composer_default", 2);
pref("extensions.adblockplus.clearStatsOnHistoryPurge", true);
pref("extensions.adblockplus.report_submiturl", "https://reports.adblockplus.org/submitReport?version=1&guid=%GUID%&lang=%LANG%");
pref("extensions.adblockplus.recentReports", []);
pref("extensions.adblockplus.hideContributeButton", true);
pref("extensions.adblockplus.blockableItemsSize", {width: 200, height: 200});
pref("extensions.adblockplus.notificationurl", "https://notification.adblockplus.org/notification.json");
pref("extensions.adblockplus.notificationdata", {});
pref("extensions.adblockplus.subscriptions_antiadblockurl", "https://easylist-downloads.adblockplus.org/antiadblockfilters.txt");
pref("extensions.adblockplus.please_kill_startup_performance", false);

==> icecat-38.6.0.en-US.win32.zip: icecat/browser/extensions/spyblock@gnu.org/defaults/prefs.js <==
// For description of these values see http://adblockplus.org/en/preferences

pref("extensions.adblockplus.currentVersion", "0.0");
pref("extensions.adblockplus.enabled", true);
pref("extensions.adblockplus.frameobjects", true);
pref("extensions.adblockplus.fastcollapse", false);
pref("extensions.adblockplus.showinstatusbar", false);
pref("extensions.adblockplus.detachsidebar", false);
pref("extensions.adblockplus.defaulttoolbaraction", 0);
pref("extensions.adblockplus.defaultstatusbaraction", 0);
pref("extensions.adblockplus.sidebar_key", "Accel Shift V, Accel Shift U");
pref("extensions.adblockplus.sendReport_key", "");
pref("extensions.adblockplus.filters_key", "Accel Shift E, Accel Shift F, Accel Shift O");
pref("extensions.adblockplus.enable_key", "");
pref("extensions.adblockplus.flash_scrolltoitem", true);
pref("extensions.adblockplus.previewimages", true);
pref("extensions.adblockplus.data_directory", "adblockplus");
pref("extensions.adblockplus.patternsbackups", 5);
pref("extensions.adblockplus.patternsbackupinterval", 24);
pref("extensions.adblockplus.whitelistschemes", "about chrome file irc moz-safe-about news resource snews x-jsd addbook cid imap mailbox nntp pop data javascript moz-icon");
pref("extensions.adblockplus.subscriptions_autoupdate", true);
pref("extensions.adblockplus.subscriptions_listurl", "https://adblockplus.org/subscriptions2.xml");
pref("extensions.adblockplus.subscriptions_fallbackurl", "https://adblockplus.org/getSubscription?version=%VERSION%&url=%SUBSCRIPTION%&downloadURL=%URL%&error=%ERROR%&channelStatus=%CHANNELSTATUS%&responseStatus=%RESPONSESTATUS%");
pref("extensions.adblockplus.subscriptions_fallbackerrors", 5);
pref("extensions.adblockplus.subscriptions_exceptionsurl", "https://easylist-downloads.adblockplus.org/exceptionrules.txt");
pref("extensions.adblockplus.subscriptions_exceptionscheckbox", true);
pref("extensions.adblockplus.documentation_link", "https://adblockplus.org/redirect?link=%LINK%&lang=%LANG%");
pref("extensions.adblockplus.savestats", true);
pref("extensions.adblockplus.composer_default", 2);
pref("extensions.adblockplus.clearStatsOnHistoryPurge", true);
pref("extensions.adblockplus.report_submiturl", "https://reports.adblockplus.org/submitReport?version=1&guid=%GUID%&lang=%LANG%");
pref("extensions.adblockplus.recentReports", []);
pref("extensions.adblockplus.hideContributeButton", false);
pref("extensions.adblockplus.blockableItemsSize", {width: 200, height: 200});
pref("extensions.adblockplus.notificationurl", "https://notification.adblockplus.org/notification.json");
pref("extensions.adblockplus.notificationdata", {});
pref("extensions.adblockplus.subscriptions_antiadblockurl", "https://easylist-downloads.adblockplus.org/antiadblockfilters.txt");
pref("extensions.adblockplus.please_kill_startup_performance", false);
pref("extensions.adblockplus.suppress_first_run_page", false);
